## jgr_distributions package

This is a simple implementation package for Gaussian and Binomial distributions.

## Files

Generaldistribution.py : the parent class for the 2 types of distribution in this package
Binomialdistribution.py : the class for binomial distribution
Gaussiandistribution.py : the class for gaussian distribution


